%global _hardened_build 1

Name:               sysdig
Version:            0.25
Release:            1%{?dist}
Summary:            Linux system exploration and troubleshooting tool with first class support for containers
License:            GPLv2+
Group:              Applications/Engineering
URL:                http://www.sysdig.org/
Source0:            https://github.com/draios/sysdig/archive/%{version}.tar.gz

Patch1:             system-unbundle.patch
Patch2:             sysdig_gprc_cpp_plugin.patch

BuildRequires:      gcc-c++
BuildRequires:      cmake
BuildRequires:      kernel
BuildRequires:      kernel-headers
BuildRequires:      kernel-devel
BuildRequires:      kernel-core
BuildRequires:      compat-lua-devel
BuildRequires:      elfutils-libelf-devel
BuildRequires:      jq-devel
BuildRequires:      jsoncpp-devel
BuildRequires:      libb64-devel
BuildRequires:      libcurl-devel
BuildRequires:      luajit-devel
BuildRequires:      ncurses-devel
BuildRequires:      openssl-devel
BuildRequires:      tbb-devel
BuildRequires:      zlib-devel
BuildRequires:      c-ares-devel
BuildRequires:      protobuf-devel
BuildRequires:      grpc-devel
BuildRequires:      grpc-plugins
#BuildRequires:     systemd

Requires:           luajit
Requires:           zlib
Requires:           ncurses
Requires:           base64
Requires:           openssl
Requires:           libcurl
Requires:           grpc
Requires:           c-ares
Requires:           protobuf

%description
Sysdig is open source, system-level exploration: capture system state and
activity from a running Linux instance, then save, filter and analyze.
Think of it as strace + tcpdump + lsof + awesome sauce.
With a little Lua cherry on top.

Sysdig instruments your physical and virtual machines at the OS level
by installing into the Linux kernel and capturing system calls and other
OS events. Then, using sysdig's command line interface, you can filter and.
decode these events in order to extract useful information. Sysdig can be used
to inspect systems live in real-time, or to generate trace files that can be
analyzed at a later stage.

%package -n dkms-sysdig
Summary:            Kernel module required for live tracing, built via dkms
Group:              System/Kernel and hardware
Provides:           kmod(sysdig.ko) = %{version}
Requires(pre):      dkms
Requires(post):     dkms
Requires(post):     systemd
Requires(post):     dkms
Requires(preun):    systemd
Requires(preun):    dkms
Requires(postun):   systemd
Requires(post):     kernel-devel
BuildArch:          noarch

%description -n dkms-sysdig
Sysdig is open source, system-level exploration: capture system state and
activity from a running Linux instance, then save, filter and analyze.
Think of it as strace + tcpdump + lsof + awesome sauce.
With a little Lua cherry on top.

Sysdig instruments your physical and virtual machines at the OS level
by installing into the Linux kernel and capturing system calls and other
OS events. Then, using sysdig's command line interface, you can filter and.
decode these events in order to extract useful information. Sysdig can be used
to inspect systems live in real-time, or to generate trace files that can be
analyzed at a later stage.

This package uses DKMS to automatically build the sysdig kernel module.

%prep
%autosetup -p1

%build
rm -f CMakeCache.txt
mkdir build
cd build

export CFLAGS="%{optflags} -Wno-return-type"
cmake \
    -DSYSDIG_VERSION=%{version} \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DUSE_BUNDLED_JSONCPP=OFF \
    -DUSE_BUNDLED_LUAJIT=OFF \
    -DUSE_BUNDLED_ZLIB=OFF \
    -DUSE_BUNDLED_NCURSES=OFF \
    -DUSE_BUNDLED_OPENSSL=OFF \
    -DUSE_BUNDLED_CURL=OFF \
    -DUSE_BUNDLED_B64=OFF \
    -DUSE_BUNDLED_JQ=OFF \
    -DUSE_BUNDLED_TBB=OFF \
    -DUSE_BUNDLED_PROTOBUF=OFF \
    -DUSE_BUNDLED_CARES=OFF \
    -DUSE_BUNDLED_GRPC=OFF \
    -DDIR_ETC=%{_sysconfdir} \
    -DBUILD_DRIVER=OFF \
    -Wno-dev ..

#    -DUSE_BUNDLED_DEPS=OFF \
#    -DBUILD_DRIVER=OFF \
#    -DUSE_BUNDLED_B64=OFF \

make %{?_smp_mflags}

%install
cd build
%make_install

rm -rf %{buildroot}%{_datadir}/zsh/

mv %{buildroot}/usr/src/sysdig* %{buildroot}%{_usrsrc}/sysdig-%{version}-%{release}

%post -n dkms-sysdig
dkms add -m sysdig -v %{version}-%{release} --rpm_safe_upgrade &&
dkms build -m sysdig -v %{version}-%{release} --rpm_safe_upgrade &&
dkms install -m sysdig -v %{version}-%{release} --rpm_safe_upgrade --force
true
/sbin/modprobe sysdig-probe

%preun -n dkms-sysdig
dkms remove --binary -m sysdig -v %{version}-%{release} --rpm_safe_upgrade --all
true
/sbin/rmmod sysdig-probe


%files
%defattr(-,root,root)
%doc COPYING README.md

%{_bindir}/csysdig
%{_bindir}/sysdig
%{_bindir}/sysdig-probe-loader

%{_datadir}/sysdig
%{_mandir}/man8/*sysdig*
%{_sysconfdir}/bash_completion.d/sysdig

%files -n dkms-sysdig
%{_usrsrc}/sysdig-%{version}-%{release}


%changelog
* Sun Mar 31 2019 josef radinger <cheese@nosuchhost.net> - 0.25-1
- bump version
- disable bundled protobuf
- disable bundled c-ares
- disable bundled grpc
- add protobuf to BuildRequires
- add c-ares to BuildRequires
- add grpc and grpc-plugins to BuildRequires
- add patch2 to correct path to gprc_cpp_plugin

* Sun Dec 30 2018 josef radinger <cheese@nosuchhost.net> - 0.24.2-1
- bump version

* Sun Dec 09 2018 josef radinger <cheese@nosuchhost.net> - 0.24.1-2
- remove dkms as Requireement from sysdig itself

* Fri Dec 07 2018 josef radinger <cheese@nosuchhost.net> - 0.24.1-1
- bump version
- fix download link
- add tbb-devel to Buildrequires
- add compat-lua-devel to Buildrequires
- add jsoncpp-devel to Buildrequires
- add jq-devel to Buildrequires
- add libb64-devel to Buildrequires
- disable use of bundled dep
